@@ -37,7 +37,7 @@ makeMBOResult.OptState = function(opt.state) {
 
   #FIXME: There has to be a better way to notice if it's multiobjective
   #also it's possible that with getOptStateFinalPoints(... unify = TRUE) we get final.points$x. But I don't know where we do that.
-  x.df = dropNamed(final.points$x, ".multifid.lvl")
+  x.df = final.points$x
   if (!is.null(x.df) && nrow(x.df) == 1) {
     if (getOptProblemControl(opt.problem)$final.evals > 0) {
       ys = evalFinalPoint(opt.state, x.df)
