@@ -66,7 +66,7 @@ checkStuff = function(fun, design, learner, control) {
 
   # If nugget estimation should be used, make sure learner is a km model with activated nugget estim
   if (infill.crit.id == "aei" && getMBOInfillCritParam(infill.crit, "aei.use.nugget")) {
-    if (learner$short.name != "km" || !isTRUE(getHyperPars(learner)$nugget.estim)) {
+    if (getLeafLearner(learner)$short.name != "km" || !(isTRUE(getHyperPars(learner)$nugget.estim) || !is.null(getHyperPars(learner)$nugget))) {
       stop("You have to turn on nugget estimation in your Kriging Model, if you want to use nugget estimation in the aei!")
     }
   }
