@@ -2,6 +2,7 @@ proposePointsMSPOT = function(opt.state, ...) {
 
   opt.problem = getOptStateOptProblem(opt.state)
   models = getOptStateModels(opt.state)$models
+  designs = getOptStateDesigns(opt.state)
   par.set = getOptProblemParSet(opt.problem)
   control = getOptProblemControl(opt.problem)
   opt.path = getOptStateOptPath(opt.state)
@@ -12,18 +13,17 @@ proposePointsMSPOT = function(opt.state, ...) {
   if (!ch$ok)
     return(ch$prop)
 
-  design = convertOptPathToDf(opt.path, control)
   infill.crit.id = getMBOInfillCritId(control$infill.crit)
   infill.opt.fun = getInfillOptFunction(control$infill.opt)
 
   # store time to propose single point
   secs = measureTime({
-    prop.points = infill.opt.fun(control$infill.crit$fun, models, control, par.set, opt.path, design, iter, ...)
+    prop.points = infill.opt.fun(control$infill.crit$fun, models, control, par.set, opt.path, designs, iter, ...)
   })
 
   ppoints = prop.points$prop.points
   crit.vals = evalCritFunForMultiObjModels(control$infill.crit$fun, ppoints, models, control,
-    par.set, design, iter)
+    par.set, designs, iter)
   crit.vals = cbind(crit.vals, prop.points$prop.hv.contrs)
   prop.type = rep(paste0("infill_", infill.crit.id), n)
 
