@@ -5,9 +5,14 @@ shouldTerminate.OptState = function(opt.state) {
   opt.problem = getOptStateOptProblem(opt.state)
   control = getOptProblemControl(opt.problem)
   stop.conds = control$stop.conds
+  progress = NULL
 
-  for (stop.cond in stop.conds) {
+  for (i in seq_along(stop.conds)) {
+    stop.cond = stop.conds[[i]]
     stop.obj = stop.cond(opt.state)
+    if (isTRUE(names(stop.conds)[i] == control$use.for.adaptive.infill)) {
+      progress = stop.obj$progress
+    }
     if (stop.obj$term) {
       # if user-defined termination condition is active, set the code by hand
       if (is.null(stop.obj$code)) {
@@ -18,5 +23,5 @@ shouldTerminate.OptState = function(opt.state) {
   }
 
   # "fallback"
-  return(list(term = FALSE, message = NA_character_, code = NA_character_))
+  return(list(term = FALSE, message = NA_character_, code = NA_character_, progress = progress))
 }
